import _ from "lodash"
import React, { useEffect, useState } from "react"
import { useCheckoutFlow } from "../../hooks/use-checkout-flow"
// import { useContactForm } from "../../hooks/use-contact-form"
import { useValidPhoneForm } from "../../hooks/use-valid-phone-form"
import ChevronLeft from "../../icons/chevron-left.svg"
import PhoneValidator from "./signup-valid-phone"
import SignupEmail from "./signup-email"
import SignupStepContainer from "./signup-step-container"
import { useAuth } from "../../hooks/use-auth"

const SignupFlow = () => {
  const { state, setState } = useCheckoutFlow()

  const update = step => {
    setState(step)
  }

  const {
    forms: { registerForm },
  } = useAuth()
  const validPhoneForm = useValidPhoneForm(setState,registerForm)
  

  let steps = [
    {
      title: "Valid Phone",
      key: 0,
      // completed: registerForm?.email !== null,
      controller: validPhoneForm,
      children: <PhoneValidator controller={validPhoneForm} />,
      handleSubmit: validPhoneForm.handleSubmit,
    },
    {
      title: "Information",
      key: 1,
      //   completed: !_.isEmpty(cart?.shipping_address?.address_1),
      controller: registerForm,
      children: <SignupEmail controller={registerForm} />,
      handleSubmit: registerForm.handleSubmit,
    },
  ]

  return (
    <>
      <div className="flex flex-col">
        {steps.map(step => {
          return (
            <SignupStepContainer
              key={step.key}
              step={step.key}
              setState={setState}
              title={step.title}
              isOpen={step.key === state}
              isCompleted={step.completed}
            >
              {step.children}
              <div className="flex items-center justify-between">
                {step.key !== 0 && (
                  <button
                    className="text-gray-700 flex items-center"
                    onClick={() => update(step.key - 1)}
                  >
                    <img
                      src={ChevronLeft}
                      alt=""
                      aria-hidden="true"
                      className="w-3 h-3 mr-2"
                    />
                    <span>Go back</span>
                  </button>
                )}
                <div />
                {step.key !== steps.length - 1 && (
                  <button
                    type="submit"
                    className="btn-ui"
                    onClick={step.handleSubmit}
                    disabled={step.controller.isSubmitting}
                  >
                    Next
                  </button>
                )}
              </div>
            </SignupStepContainer>
          )
        })}
      </div>
      {/* <CheckoutSummary
        cart={cart}
        shippingOption={shippingOptionController.selectedShippingMethod}
      /> */}
    </>
  )
}

export default SignupFlow
