import { Dialog, Transition, Disclosure } from "@headlessui/react"
import React, { Fragment } from "react"

import { XIcon } from "@heroicons/react/outline"
import { ChevronDownIcon } from "@heroicons/react/solid"
import { classNames } from "../../utils/class-names"
const MobileProductFilter = ({
  open,
  setOpen,
  filterables,
  activeFilters,
  setActiveFilters,
}) => {
  const handleChange = e => {
    const { key, value } = JSON.parse(e.target.value)
    console.log("target =>", e.target)
    console.log("=>", key, ",", value)
    const tmp = { ...activeFilters }
    console.log("e.target.checked", e.target.checked)
    if (e.target.checked) {
      if (!tmp[key]) {
        tmp[key] = []
      }

      tmp[key].push(value)
    } else {
      tmp[key] = tmp[key].filter(item => item !== value)

      if (tmp[key].length === 0) {
        delete tmp[key]
      }
    }
    setActiveFilters(tmp)
  }

  return (
    <Transition.Root show={open} as={Fragment}>
      <Dialog
        as="div"
        className="fixed inset-0 flex z-40 sm:hidden"
        onClose={setOpen}
      >
        <Transition.Child
          as={Fragment}
          enter="transition-opacity ease-linear duration-300"
          enterFrom="opacity-0"
          enterTo="opacity-100"
          leave="transition-opacity ease-linear duration-300"
          leaveFrom="opacity-100"
          leaveTo="opacity-0"
        >
          <Dialog.Overlay className="fixed inset-0 bg-black bg-opacity-25" />
        </Transition.Child>

        <Transition.Child
          as={Fragment}
          enter="transition ease-in-out duration-300 transform"
          enterFrom="translate-x-full"
          enterTo="translate-x-0"
          leave="transition ease-in-out duration-300 transform"
          leaveFrom="translate-x-0"
          leaveTo="translate-x-full"
        >
          <div className="ml-auto relative max-w-xs w-full h-full bg-white shadow-xl py-4 pb-12 flex flex-col overflow-y-auto">
            <div className="px-4 flex items-center justify-between">
              <h2 className="text-lg font-medium text-gray-900">Filters</h2>
              <button
                type="button"
                className="-mr-2 w-10 h-10 bg-white p-2 rounded-md flex items-center justify-center text-gray-400"
                onClick={() => setOpen(false)}
              >
                <span className="sr-only">Close menu</span>
                <XIcon className="h-6 w-6" aria-hidden="true" />
              </button>
            </div>

            {/* Filters */}
            <form className="mt-4">
              {Object.keys(filterables).map(key => (
                <Disclosure
                  as="div"
                  key={key}
                  className="border-t border-gray-200 px-4 py-6"
                >
                  {({ open }) => (
                    <>
                      <h3 className="-mx-2 -my-3 flow-root">
                        <Disclosure.Button className="px-2 py-3 bg-white w-full flex items-center justify-between text-sm text-gray-400">
                          <span className="font-medium text-gray-900">
                            {filterables[key].title}
                          </span>
                          <span className="ml-6 flex items-center">
                            <ChevronDownIcon
                              className={classNames(
                                open ? "-rotate-180" : "rotate-0",
                                "h-5 w-5 transform"
                              )}
                              aria-hidden="true"
                            />
                          </span>
                        </Disclosure.Button>
                      </h3>
                      <Disclosure.Panel className="pt-6">
                        <div className="space-y-6">
                          {filterables[key].values.map((option, optionIdx) => {
                            const checked =
                              activeFilters?.[key] &&
                              activeFilters[key].includes(option)
                            return (
                              <div
                                key={optionIdx}
                                className="flex items-center"
                              >
                                <input
                                  id={`filter-mobile-${key}-${optionIdx}`}
                                  name={`${optionIdx}[]`}
                                  defaultChecked={checked}
                                  // defaultValue={option}
                                  type="checkbox"
                                  value={JSON.stringify({
                                    key: key,
                                    value: option,
                                  })}
                                  onChange={handleChange}
                                  className="h-4 w-4 border-gray-300 rounded text-indigo-600 focus:ring-indigo-500"
                                />
                                <label
                                  htmlFor={`filter-mobile-${key}-${optionIdx}`}
                                  className="ml-3 text-sm text-gray-500"
                                >
                                  {option}
                                </label>
                              </div>
                            )
                          })}
                        </div>
                      </Disclosure.Panel>
                    </>
                  )}
                </Disclosure>
              ))}
            </form>
          </div>
        </Transition.Child>
      </Dialog>
    </Transition.Root>
  )
}

export default MobileProductFilter
