import { navigate } from "gatsby"
import React, { useState, useMemo } from "react"
import { useCart } from "../../../hooks/use-cart"
// import { useMedusa } from "../../../hooks/use-medusa"
import ErrorMessage from "../../utility/error-message"
import isPc from "../../../utils/isPc"

const AlipayPayment = () => {
  const {
    cart,
    actions: { completeCart, setPaymentSession },
  } = useCart()

  const [processing, setProcessing] = useState(false)

  const aliPaySession = useMemo(() => {
    if (cart.payment_sessions) {
      return cart.payment_sessions.find(s => s.provider_id === "alipay")
    }
    return null
  }, [cart.payment_sessions])

  if (!aliPaySession) {
    return null
  }

  const link = {
    wap: aliPaySession.data.wap,
    page: aliPaySession.data.page,
  }

  const handleTestPayment = async () => {
    setProcessing(true)
    // 创建session
    const cart = await setPaymentSession("alipay")

    //
    if (!cart) {
      setProcessing(false)
      return
    }
    if (isPc()) {
      navigate(link.page)
    }
    navigate(link.wap)
  }

  return (
    <div className="flex flex-col">
      <ErrorMessage
        error={
          "This is for testing purposes only, and should not be used in a production environment."
        }
      />
      <button
        className="btn-ui my-4"
        onClick={handleTestPayment}
        disabled={processing}
      >
        {processing ? "Processing..." : "支付宝"}
      </button>
    </div>
  )
}

export default AlipayPayment
