import { GatsbyImage } from "gatsby-plugin-image"
import React, { useMemo } from "react"
import { usePrice } from "../../hooks/use-price"
import { useRegion } from "../../hooks/use-region"
import RegionalLink from "../utility/regional-link"

const TrendingListItem = ({ product }) => {
  const {
    actions: { getFromPrice },
  } = usePrice()

  const { region } = useRegion()

  const fromPrice = useMemo(() => {
    return getFromPrice(product, region?.currency_code)
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [product, region?.currency_code])

  return (
    <RegionalLink to={product.handle} >
      <li
        key={product.id}
        className="w-64 flex-col text-center lg:w-auto "
      >
        <div className="group relative">
          <div className="w-full min-h-auto bg-gray-100 rounded-md overflow-hidden aspect-w-1 aspect-h-1 rounded-md overflow-hidden group-hover:opacity-75 lg:h-80 lg:aspect-none">
            <GatsbyImage
              image={product.thumbnail?.childImageSharp?.gatsbyImageData}
              alt={product.title}
              className="w-full h-full object-center object-cover group-hover:opacity-75"
            />
          </div>
          <div className="mt-6">
            <h3 className="mt-1 font-semibold text-gray-900">
              <a href={product.href}>
                <span className="absolute inset-0" />
                {product.title}
              </a>
            </h3>
            <p className="mt-1 text-gray-900">{fromPrice}</p>
          </div>
        </div>
      </li>
    </RegionalLink>
  )
}

export default TrendingListItem
