import { useFormik } from "formik"
import { navigate } from "gatsby"
import Validator from "../utils/validator"
import { useCustomer } from "./use-customer"
import api from "../services/api"
export const useAuth = () => {
  // const isLoading=false
  const {
    actions: { loginCustomer, createCustomer },
  } = useCustomer()

  const send_sms = async phone => {
    return api.auth.sms(phone)
  }
  const valid_phone = async ({ phone, code }) => {
    return api.auth.valid({ phone, code })
  }
  const is_valid = phone => {
    return api.auth.check(phone)
  }
  const loginForm = useFormik({
    initialValues: {
      email: "",
      password: "",
    },
    validationSchema: Validator.loginSchema,
    validateOnChange: false,
    validateOnBlur: false,
    onSubmit: async (values, { setStatus, validateForm }) => {
      const validationResponse = await validateForm(values)

      if (Object.keys(validationResponse).length > 0) {
        setStatus(validationResponse)
        return
      }

      const response = await loginCustomer(values)

      if (response.error) {
        setStatus({ authError: response.error })
        return
      }

      navigate("/")
    },
  })

  const registerForm = useFormik({
    initialValues: {
      first_name: "",
      last_name: "",
      email: "",
      phone: "",
      password: "",
    },
    validationSchema: Validator.registerSchema,
    validateOnChange: false,
    validateOnBlur: false,
    onSubmit: async (values, { setStatus, validateForm }) => {
      const validationResponse = await validateForm(values)

      if (Object.keys(validationResponse).length > 0) {
        setStatus(validationResponse)
        return
      }
      await is_valid(values.phone)
        .then(async () => {
          const response = await createCustomer(values)

          if (response.error) {
            setStatus({ authError: response.error })
            return
          }
          navigate("/")
        })
        .catch(error => {
          console.log(error)
        })
    },
  })
  return {
    forms: {
      loginForm,
      registerForm,
    },
    send_sms,
    valid_phone,
  }
}
