import { graphql } from "gatsby"
// import { StaticImage } from "gatsby-plugin-image"
import React from "react"
import CollectionPreview from "../components/categories/collection-preview"
// import ProductListItem from "../components/products/product-list-item"
import TrendingListItem from "../components/products/trending-products-list"
// import Grid from "../components/utility/grid"
import SearchEngineOptimization from "../components/utility/seo"
import { useCollections } from "../hooks/use-collections"
import { GatsbyImage, getImage } from "gatsby-plugin-image"

const IndexPage = ({ data }) => {
  const { products, collections, page } = data
  const prods = data.products.edges.map(edge => edge.node)
  const collectionPreviews = useCollections(collections, products)
  const mainHero =
    page.contentModules && page.contentModules.length >= 1
      ? page.contentModules[0]
      : null
  // axios
  //   .post("http://localhost:9000/alipay/trade", {
  //     isWap: false,
  //     cartId: "cart_01FXSBFHH94CW2MQJCVCADM8FW",
  //   })
  //   .then(res => {
  //     console.log(res)
  //   })

  return (
    <div>
      <SearchEngineOptimization title="Home" />

      {/* HERO section */}
      <div className="relative">
        <div
          aria-hidden="true"
          className="hidden absolute w-1/2 h-full bg-gray-100 lg:block"
        />
        <div className="relative bg-gray-100 lg:bg-transparent">
          <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 lg:grid lg:grid-cols-2">
            <div className="max-w-2xl mx-auto py-24 lg:py-64 lg:max-w-none">
              <div className="lg:pr-16">
                <h1 className="text-4xl font-extrabold tracking-tight text-gray-900 sm:text-5xl xl:text-6xl">
                  {/* {asts.} */}
                  {mainHero.title}
                </h1>
                <p className="mt-4 text-xl text-gray-600">{mainHero.cta}</p>
                <div className="mt-6">
                  <a
                    href={mainHero.link.linkTo}
                    className="btn-ui mt-4 min-w-full lg:min-w-0 inline-block bg-indigo-600 border border-transparent py-3 px-8 rounded-md font-medium text-white hover:bg-indigo-700"
                  >
                    {mainHero.link.title}
                  </a>
                </div>
              </div>
            </div>
          </div>
        </div>
        <div className="w-full h-48 sm:h-64 lg:absolute lg:top-0 lg:right-0 lg:w-1/2 lg:h-full">
          <GatsbyImage
            image={getImage(mainHero.backgroundImage)}
            // src={mainHero.backgroundImage.gatsbyImageData.images.src}
            alt=""
            className="w-full h-full object-center object-cover"
          />
        </div>
      </div>

      {/* Trending products */}

      <section aria-labelledby="trending-heading" className="bg-white">
        <div className="py-16 sm:py-24 lg:max-w-7xl lg:mx-auto lg:py-32 lg:px-8">
          <div className="px-4 flex items-center justify-between sm:px-6 lg:px-0">
            <h2
              id="trending-heading"
              className="text-2xl font-extrabold tracking-tight text-gray-900"
            >
              Trending products
            </h2>
            <a
              href="/products"
              className="hidden sm:block text-sm font-semibold text-indigo-600 hover:text-indigo-500"
            >
              See everything<span aria-hidden="true"> &rarr;</span>
            </a>
          </div>

          <div className="mt-8 relative">
            <div className="relative w-full overflow-x-auto">
              <ul
                role="list"
                className="mx-4 inline-flex space-x-8 sm:mx-6 lg:mx-0 lg:space-x-0 lg:grid lg:grid-cols-4 lg:gap-x-8"
              >
                {prods.slice(0, 4).map(p => {
                  return <TrendingListItem product={p} key={p.handle} />
                })}
              </ul>
            </div>
          </div>

          <div className="mt-12 px-4 sm:hidden">
            <a
              href="#"
              className="text-sm font-semibold text-indigo-600 hover:text-indigo-500"
            >
              See everything<span aria-hidden="true"> &rarr;</span>
            </a>
          </div>
        </div>
      </section>

      {/* Feature */}
      <section
        aria-labelledby="social-impact-heading"
        className="max-w-7xl mx-auto pt-24 px-4 sm:pt-32 sm:px-6 lg:px-8"
      >
        <div className="relative rounded-lg overflow-hidden">
          <div className="absolute inset-0">
            <img
              src="https://tailwindui.com/img/ecommerce-images/home-page-01-feature-section-01.jpg"
              alt=""
              className="w-full h-full object-center object-cover"
            />
          </div>
          <div className="relative bg-gray-900 bg-opacity-75 py-32 px-6 sm:py-40 sm:px-12 lg:px-16">
            <div className="relative max-w-3xl mx-auto flex flex-col items-center text-center">
              <h2
                id="social-impact-heading"
                className="text-3xl font-extrabold tracking-tight text-white sm:text-4xl"
              >
                <span className="block sm:inline">Level up</span>
                <span className="block sm:inline">your desk</span>
              </h2>
              <p className="mt-3 text-xl text-white">
                Make your desk beautiful and organized. Post a picture to social
                media and watch it get more likes than life-changing
                announcements. Reflect on the shallow nature of existence. At
                least you have a really nice desk setup.
              </p>
              <a
                href="#"
                className="mt-8 w-full block bg-white border border-transparent rounded-md py-3 px-8 text-base font-medium text-gray-900 hover:bg-gray-100 sm:w-auto"
              >
                Shop Workspace
              </a>
            </div>
          </div>
        </div>
      </section>

      {/* Collection section */}
      <section
        aria-labelledby="collection-heading"
        className="max-w-xl mx-auto pt-24 px-4 sm:pt-32 sm:px-6 lg:max-w-7xl lg:px-8"
      >
        <h2
          id="collection-heading"
          className="text-2xl font-extrabold tracking-tight text-gray-900"
        >
          Shop by Collection
        </h2>
        <p className="mt-4 text-base text-gray-500">
          Each season, we collaborate with world-class designers to create a
          collection inspired by the natural world.
        </p>

        <div className="mt-10 space-y-12 lg:space-y-0 lg:grid lg:grid-cols-3 lg:gap-x-8">
          {collectionPreviews.slice(0, 4).map(collection => {
            return (
              <CollectionPreview key={collection.id} collection={collection} />
            )
          })}
        </div>
      </section>

      {/* Featured section */}
      <section
        aria-labelledby="comfort-heading"
        className="max-w-7xl mx-auto py-24 px-4 sm:py-32 sm:px-6 lg:px-8"
      >
        <div className="relative rounded-lg overflow-hidden">
          <div className="absolute inset-0">
            <img
              src="https://tailwindui.com/img/ecommerce-images/home-page-01-feature-section-02.jpg"
              alt=""
              className="w-full h-full object-center object-cover"
            />
          </div>
          <div className="relative bg-gray-900 bg-opacity-75 py-32 px-6 sm:py-40 sm:px-12 lg:px-16">
            <div className="relative max-w-3xl mx-auto flex flex-col items-center text-center">
              <h2
                id="comfort-heading"
                className="text-3xl font-extrabold tracking-tight text-white sm:text-4xl"
              >
                Simple productivity
              </h2>
              <p className="mt-3 text-xl text-white">
                Endless tasks, limited hours, a single piece of paper. Not
                really a haiku, but we're doing our best here. No kanban boards,
                burndown charts, or tangled flowcharts with our Focus system.
                Just the undeniable urge to fill empty circles.
              </p>
              <a
                href="#"
                className="mt-8 w-full block bg-white border border-transparent rounded-md py-3 px-8 text-base font-medium text-gray-900 hover:bg-gray-100 sm:w-auto"
              >
                Shop Focus
              </a>
            </div>
          </div>
        </div>
      </section>
    </div>
  )
}

export const query = graphql`
  query {
    products: allMedusaProducts {
      edges {
        node {
          handle
          title
          collection_id
          thumbnail {
            childImageSharp {
              gatsbyImageData
            }
          }
          variants {
            prices {
              amount
              currency_code
            }
          }
        }
      }
    }
    collections: allMedusaCollections {
      edges {
        node {
          id
          title
          handle
        }
      }
    }
    page: contentfulPage(title: { eq: "Home" }) {
      title
      contentModules {
        ... on ContentfulHero {
          id
          backgroundImage {
            gatsbyImageData
          }
          title
          cta
          link {
            title
            linkTo
          }
        }
      }
    }
  }
`

export default IndexPage
