import React, { Fragment, useState } from "react"
import MobileProductFilter from "../components/categories/mobile-product-filter"
import ProductFilter from "../components/products/product-filter"
import ProductListItem from "../components/products/product-list-item"
import SearchEngineOptimization from "../components/utility/seo"
import { useFilter } from "../hooks/use-filter"

const Collection = ({ pageContext }) => {
  const [open, setOpen] = useState(false)
  const [activeFilters, setActiveFilters] = useState(null)
  const { title, filterables, products } = pageContext
  const filteredProducts = useFilter(products, activeFilters)

  return (
    <Fragment>
      <SearchEngineOptimization title={title} />
      <MobileProductFilter
        open={open}
        setOpen={setOpen}
        filterables={filterables}
        activeFilters={activeFilters}
        setActiveFilters={setActiveFilters}
      />
      <div className="bg-white">
        <div className="max-w-7xl mx-auto py-16 px-4 sm:px-6 lg:px-8">
          <h1 className="text-3xl font-extrabold tracking-tight text-gray-900">
            {title}
          </h1>
          <p className="mt-4 max-w-xl text-sm text-gray-700">
            Our thoughtfully designed workspace objects are crafted in limited
            runs. Improve your productivity and organization with these sale
            items before we run out.
          </p>
        </div>
      </div>
      <ProductFilter
        filterables={filterables}
        activeFilters={activeFilters}
        setActiveFilters={setActiveFilters}
      />

      <section
        aria-labelledby="products-heading"
        className="max-w-2xl mx-auto pt-12 pb-16 px-4 sm:pt-16 sm:pb-24 sm:px-6 lg:max-w-7xl lg:px-8"
      >
        <h2 id="products-heading" className="sr-only">
          Products
        </h2>

        <div className="grid grid-cols-1 gap-y-10 sm:grid-cols-2 gap-x-6 lg:grid-cols-3 xl:grid-cols-4 xl:gap-x-8">
          {filteredProducts.map(product => {
            return <ProductListItem key={product.handle} product={product} />
          })}
        </div>
      </section>
    </Fragment>
  )
}

export default Collection
